# swagger-java-client

Lightning - A Weather Source API
- API version: 2.0.0
  - Build date: 2020-11-20T19:54:05.861Z[GMT]

**This API is in BETA release.**  Global lightning archive, updated in real time. The Weather Source Lightning API provides the most accurate and reliable global lightning data available. All matching lightning events within 12 km (7 miles) of a provided location (and within the provided time range) are returned. The global lightning archive is available from the years 2021 and onward.  **IMPORTANT:** To authenticate to the Weather Source Lightning API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 

  For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

*Automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen)*


## Requirements

Building the API client library requires:
1. Java 1.7+
2. Maven/Gradle

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>io.swagger</groupId>
  <artifactId>swagger-java-client</artifactId>
  <version>1.0.0</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/swagger-java-client-1.0.0.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java
import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.OnpointsApi;

import java.io.File;
import java.util.*;

public class OnpointsApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure API key authorization: ApiKeyAuth
        ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
        ApiKeyAuth.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //ApiKeyAuth.setApiKeyPrefix("Token");

        OnpointsApi apiInstance = new OnpointsApi();
        Integer onpointId = 56; // Integer | An OnPoint™ ID.
        OffsetDateTime timestampStart = new OffsetDateTime(); // OffsetDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
        OffsetDateTime timestampEnd = new OffsetDateTime(); // OffsetDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
        List<String> fields = Arrays.asList("fields_example"); // List<String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** 
        String unitScale = "IMPERIAL"; // String | The unit scale for returned values.<br>
        Integer limit = 0; // Integer | Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit. 
        try {
            LightningOnpointObj result = apiInstance.onpointsOnpointIdPeriodTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, limit);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling OnpointsApi#onpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            e.printStackTrace();
        }
    }
}
```

## Documentation for API Endpoints

All URIs are relative to *https://lightning.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OnpointsApi* | [**onpointsOnpointIdPeriodTimestampStarttimestampEndGet**](docs/OnpointsApi.md#onpointsOnpointIdPeriodTimestampStarttimestampEndGet) | **GET** /onpoints/{onpointId}/period/{timestampStart},{timestampEnd} | Lightning data proximate to an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudePeriodTimestampStarttimestampEndGet**](docs/PointsApi.md#pointsLatitudelongitudePeriodTimestampStarttimestampEndGet) | **GET** /points/{latitude},{longitude}/period/{timestampStart},{timestampEnd} | Lightning data proximate to a Latitude/Longitude point.

## Documentation for Models

 - [BoundingPoints](docs/BoundingPoints.md)
 - [BoundingPointsInner](docs/BoundingPointsInner.md)
 - [ErrorObj](docs/ErrorObj.md)
 - [FieldListObj](docs/FieldListObj.md)
 - [Fields](docs/Fields.md)
 - [Grid](docs/Grid.md)
 - [LightningArr](docs/LightningArr.md)
 - [LightningObj](docs/LightningObj.md)
 - [LightningOnpointObj](docs/LightningOnpointObj.md)
 - [LightningPointObj](docs/LightningPointObj.md)
 - [OnpointObj](docs/OnpointObj.md)
 - [PointObj](docs/PointObj.md)

## Documentation for Authorization

Authentication schemes defined for the API:
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

support@weathersource.com
