# PointsApi

All URIs are relative to *https://lightning.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**pointsLatitudelongitudePeriodTimestampStarttimestampEndGet**](PointsApi.md#pointsLatitudelongitudePeriodTimestampStarttimestampEndGet) | **GET** /points/{latitude},{longitude}/period/{timestampStart},{timestampEnd} | Lightning data proximate to a Latitude/Longitude point.

<a name="pointsLatitudelongitudePeriodTimestampStarttimestampEndGet"></a>
# **pointsLatitudelongitudePeriodTimestampStarttimestampEndGet**
> LightningPointObj pointsLatitudelongitudePeriodTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, limit)

Lightning data proximate to a Latitude/Longitude point.

Returns all lightning events that are both within 12 km (7 miles) of a provided Latitude/Longitude point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.PointsApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure API key authorization: ApiKeyAuth
ApiKeyAuth ApiKeyAuth = (ApiKeyAuth) defaultClient.getAuthentication("ApiKeyAuth");
ApiKeyAuth.setApiKey("YOUR API KEY");
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.setApiKeyPrefix("Token");

PointsApi apiInstance = new PointsApi();
Float latitude = 3.4F; // Float | A latitude value between -90° and 90°.
Float longitude = 3.4F; // Float | A longitude value between -180° (West) and 180° (East).
OffsetDateTime timestampStart = new OffsetDateTime(); // OffsetDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
OffsetDateTime timestampEnd = new OffsetDateTime(); // OffsetDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
List<String> fields = Arrays.asList("fields_example"); // List<String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** 
String unitScale = "IMPERIAL"; // String | The unit scale for returned values.<br>
Integer limit = 0; // Integer | Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit. 
try {
    LightningPointObj result = apiInstance.pointsLatitudelongitudePeriodTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, limit);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling PointsApi#pointsLatitudelongitudePeriodTimestampStarttimestampEndGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **Float**| A latitude value between -90° and 90°. |
 **longitude** | **Float**| A longitude value between -180° (West) and 180° (East). |
 **timestampStart** | **OffsetDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. |
 **timestampEnd** | **OffsetDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. |
 **fields** | [**List&lt;String&gt;**](String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  | [enum: timestamp, latitude, longitude, distance, peakCurrent, flashMult, sensorCnt, df, t, su, sv, chi2, riseTime, fallTime, rateOfChange, cloudFlag, angleFlag, signalFlag, timingFlag, all, allBasic, allMeta, allConfidence]
 **unitScale** | **String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]
 **limit** | **Integer**| Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  | [optional] [default to 0]

### Return type

[**LightningPointObj**](LightningPointObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

